@@ -1,11 +1,10 @@
 package Pod::Elemental::Element::Pod5::Data;
-our $VERSION = '0.092940';
+our $VERSION = '0.092941';
 
 
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Text';
-with    'Pod::Elemental::Autoblank';
-# ABSTRACT: a POD data paragraph
+# ABSTRACT: a Pod data paragraph
 
 
 use namespace::autoclean;
@@ -17,11 +16,11 @@ __END__
 
 =head1 NAME
 
-Pod::Elemental::Element::Pod5::Data - a POD data paragraph
+Pod::Elemental::Element::Pod5::Data - a Pod data paragraph
 
 =head1 VERSION
 
-version 0.092940
+version 0.092941
 
 =head1 OVERVIEW
 
