@@ -1,17 +1,21 @@
 use strict;
 use warnings;
 package Pod::Elemental::Types;
-our $VERSION = '0.092940';
+our $VERSION = '0.092941';
 
 
 # ABSTRACT: data types for Pod::Elemental
-use MooseX::Types -declare => [ qw(FormatName) ];
+use MooseX::Types -declare => [ qw(FormatName ChompedString) ];
 use MooseX::Types::Moose qw(Str);
 
 
 # Probably needs refining -- rjbs, 2009-05-26
 subtype FormatName, as Str, where { length $_ and /\A\S+\z/ };
 
+
+subtype ChompedString, as Str, where { ! /\n\z/ };
+coerce ChompedString, from Str, via { chomp; $_ };
+
 1;
 
 __END__
@@ -23,7 +27,7 @@ Pod::Elemental::Types - data types for Pod::Elemental
 
 =head1 VERSION
 
-version 0.092940
+version 0.092941
 
 =head1 OVERVIEW
 
@@ -36,6 +40,16 @@ This is a library of MooseX::Types types used by Pod::Elemental.
 This is a valid name for a format (a Pod5::Region).  It does not expect the
 leading colon for pod-like regions.
 
+=cut
+
+=pod
+
+
+=head2 ChompedString
+
+This is a string that does not end with newlines.  It can be coerced from a
+Str ending in a single newline -- the newline is dropped.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
